TmpFileObject

Struct TmpFileObject 

pub struct TmpFileObject {
    node: Arc<TmpNode>,
    position: RwLock<u64>,
    device_guard: Option<Arc<dyn Device>>,
    socket_ref: Option<Arc<dyn SocketObject>>,
    mmap_backing: RwLock<Option<Box<[Page]>>>,
    mmap_backing_len: Mutex<usize>,
    mmap_ranges: RwLock<BTreeMap<usize, MmapRange>>,
}
File object for TmpFS operations

TmpFileObject represents an open file or directory in TmpFS.

It maintains the current file position and, for device files, an optional device guard. For socket files, it maintains a reference to the socket object.

Fields

node: Arc<TmpNode>

Reference to the TmpNode

position: RwLock<u64>

Current file position

device_guard: Option<Arc<dyn Device>>

Optional device guard for device files

socket_ref: Option<Arc<dyn SocketObject>>

Optional socket reference for socket files

mmap_backing: RwLock<Option<Box<[Page]>>>

Page-aligned backing for private mmap operations

mmap_backing_len: Mutex<usize>

Byte length of the mmap backing (file size snapshot)

mmap_ranges: RwLock<BTreeMap<usize, MmapRange>>

Active mmap ranges keyed by starting virtual address

Implementations

Source

impl TmpFileObject

pub fn new_regular(node: Arc<TmpNode>) -> Self

Create a new file object for regular files

pub fn new_directory(node: Arc<TmpNode>) -> Self

Create a new file object for directories

pub fn new_device(node: Arc<TmpNode>, info: DeviceFileInfo) -> Self

Create a new file object for device files

pub fn new_socket(node: Arc<TmpNode>, info: SocketFileInfo) -> Self

Create a new file object for socket files

fn ensure_mmap_backing( &self, file_size: usize, required_size: usize, ) -> Result<(), StreamError>

fn read_device(&self, buffer: &mut [u8]) -> Result<usize, FileSystemError>

fn read_regular_file(&self, buffer: &mut [u8]) -> Result<usize, FileSystemError>

fn write_device(&self, buffer: &[u8]) -> Result<usize, FileSystemError>

fn write_regular_file(&self, buffer: &[u8]) -> Result<usize, FileSystemError>

fn read_socket(&self, buffer: &mut [u8]) -> Result<usize, StreamError>

fn write_socket(&self, buffer: &[u8]) -> Result<usize, StreamError>